/*
 *  Copyright (c) 2016 Laszlo Fazekas <mneko@freemail.hu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef CSV_LAYER_RECORD_H_
#define CSV_LAYER_RECORD_H_

#include <QString>

#include "kis_raster_keyframe_channel.h"

class CSVLayerRecord
{
public:
    CSVLayerRecord();
    virtual ~CSVLayerRecord();

    QString     name;
    QString     blending;
    float       density;
    int         visible;

    KisLayer*   layer;
    KisRasterKeyframeChannel *channel;
    QString     last;
    QString     path;
    int         frame;
};

#endif
